---

slug: /seekdb-commands
---

# obshell seekdb commands

This topic describes the seekdb commands in obshell. You can use the commands to manage a seekdb instance. You can use the `-h`/`--help` option in a command to view the help information of the command, for example, `obshell seekdb start -h`. You can also use the `-v`/`--verbose` option to view the detailed execution process of the command.

:::info
   The seekdb commands are designed for managing a seekdb instance. You do not need to explicitly specify the <code>--seekdb</code> option when you execute these commands. 
:::

## obshell seekdb start

You can run this command to start seekdb.

```shell
obshell seekdb start [--port] [--seekdb] [-6]

# example
obshell seekdb start --port 2886
```

The following table describes the options.

| Option | Required | Data Type | Default Value | Description |
| --- | --- | --- | --- | --- |
| --port | No | int | 2886 | The port number of obshell. If you do not want to specify the port number by using this option, you can also specify it by using the environment variable `OBSHELL_PORT_FOR_SEEKDB`. |
| --seekdb | No | N/A | N/A | This option does not require a value. If you specify this option, the command applies to seekdb. |
|  -6/--use-ipv6 | No | N/A | N/A | This option does not require a value. If you specify this option, IPv6 is used.  |

## obshell seekdb restart

You can run this command to restart seekdb.

```shell
obshell seekdb restart [-t] [--port] [--seekdb] [-6] [-y]

# example
obshell seekdb restart -t --port 2886
```

The following table describes the options.

| Option | Required | Data Type | Default Value | Description |
| --- | --- | --- | --- | --- |
| -t/--terminate | No | N/A | N/A | This option does not require a value. If you specify this option, the `MINOR FREEZE` command is triggered before seekdb is restarted. |
| --port | No | int | 2886 | The port number of obshell. If you do not want to specify the port number by using this option, you can also specify it by using the environment variable `OBSHELL_PORT_FOR_SEEKDB`. |
| --seekdb | No | N/A | N/A | This option does not require a value. If you specify this option, the command applies to seekdb. |
|  -6/--use-ipv6 | No | N/A | N/A | This option does not require a value. If you specify this option, IPv6 is used.  |
| -y/--yes  | No | N/A | N/A | This option does not require a value. If you specify this option, the confirmation for the restart operation is skipped. |

## obshell seekdb stop

You can run this command to stop seekdb.

```shell
obshell seekdb stop [-t] [--port] [--seekdb] [-6] [-y]

# example
obshell agent stop -t --port 2886
```

The following table describes the options.

| Option | Required | Data Type | Default Value | Description |
| --- | --- | --- | --- | --- |
| -t/--terminate | No | N/A | N/A | This option does not require a value. If you specify this option, the `MINOR FREEZE` command is triggered before the seekdb process is stopped. |
| --port | No | int | 2886 | The port number of obshell. If you do not want to specify the port number by using this option, you can also specify it by using the environment variable `OBSHELL_PORT_FOR_SEEKDB`. |
| --seekdb | No | N/A | N/A | This option does not require a value. If you specify this option, the command applies to seekdb. |
|  -6/--use-ipv6 | No | N/A | N/A | This option does not require a value. If you specify this option, IPv6 is used.  |
| -y/--yes  | No | N/A | N/A | This option does not require a value. If you specify this option, the confirmation for the stop operation is skipped. |

## obshell seekdb show

You can run this command to view the configurations and status of seekdb.

```shell
obshell seekdb show [-d] [--port] [--seekdb] [-6]

# example
obshell agent show
```

The following table describes the options.

| Option | Required | Data Type | Default Value | Description |
| --- | --- | --- | --- | --- |
| -d/--show_detail | No | N/A | N/A | This option does not require a value. If you specify this option, the command displays the details of seekdb.  |
| --port | No | int | 2886 | Specifies the port number of obshell. If you do not want to specify the port number by using this option, you can also specify the port number of obshell by using the environment variable `OBSHELL_PORT_FOR_SEEKDB`.  |
| --seekdb | No | N/A | N/A | This option does not require a value. If you specify this option, the command applies to seekdb.  |
| -6/--use-ipv6 | No | N/A | N/A | This option does not require a value. If you specify this option, IPv6 is used.  |
